=============
metricd-agent
=============

.. image:: https://travis-ci.org/o/metric-agent.svg?branch=master

metricd is agent for collecting and sending metrics. Currently collects information about system and sends as JSON via HTTP. In the future more reporters will be available.